package com.qmth.sop.business.util;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.qmth.sop.common.util.JacksonUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.lang.ref.SoftReference;
import java.util.Objects;
import java.util.concurrent.ConcurrentHashMap;

/**
 * @Description: 软引用缓存
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2023/12/27
 */
public class SoftReferenceUtil {

    private final static Logger log = LoggerFactory.getLogger(SoftReferenceUtil.class);

    private static ConcurrentHashMap<String, SoftReference<Object>> softReferenceMap = new ConcurrentHashMap<>();

    public static void set(String key, Object o) {
        softReferenceMap.put(key, new SoftReference<>(o));
    }

    public static Object get(String key) {
        return Objects.nonNull(softReferenceMap.get(key)) ? softReferenceMap.get(key).get() : null;
    }

    public static void remove(String key) {
        softReferenceMap.remove(key);
    }

    public static JSONArray getAll() {
        JSONArray jsonArray = new JSONArray();
        for (Object key : softReferenceMap.keySet()) {
            Object o = softReferenceMap.get(key).get();
            JSONObject jsonObject = new JSONObject();
            jsonObject.put(key.toString(), JacksonUtil.parseJson(o));
            jsonArray.add(jsonObject);
        }
        return jsonArray;
    }

//    public static void main(String[] args) {
//        SoftReferenceUtil.set("A", 1);
//        SoftReferenceUtil.set("B", 2);
//        System.out.println(SoftReferenceUtil.get("A"));
//        System.out.println(SoftReferenceUtil.get("B"));
//        JSONArray jsonArray = SoftReferenceUtil.getAll();
//        System.out.println(jsonArray.toJSONString());
//        SoftReferenceUtil.remove("B");
//        System.out.println(SoftReferenceUtil.get("B"));
//    }
}
